@@ -3,12 +3,12 @@ package tui
 import (
 	"strconv"
 
-	"github.com/dundee/gdu/v5/pkg/analyze"
+	"golang.org/x/text/cases"
+	"golang.org/x/text/language"
+
 	"github.com/dundee/gdu/v5/pkg/fs"
 	"github.com/gdamore/tcell/v2"
 	"github.com/rivo/tview"
-	"golang.org/x/text/cases"
-	"golang.org/x/text/language"
 )
 
 func (ui *UI) fileItemMarked(row int) {
@@ -70,8 +70,8 @@ func (ui *UI) deleteMarked(shouldEmpty bool) {
 
 			var deleteItems []fs.Item
 			if shouldEmpty && one.IsDir() {
-				currentDir = one.(*analyze.Dir)
-				for _, file := range currentDir.GetFiles() {
+				currentDir = one
+				for file := range currentDir.GetFiles(fs.SortBySize, fs.SortDesc) {
 					deleteItems = append(deleteItems, file)
 				}
 			} else {
@@ -95,6 +95,7 @@ func (ui *UI) deleteMarked(shouldEmpty bool) {
 		}
 
 		ui.app.QueueUpdateDraw(func() {
+			ui.pages.RemovePage(acting)
 			ui.pages.RemovePage(acting)
 			ui.markedRows = make(map[int]struct{})
 			x, y := ui.table.GetOffset()
